==> zio-aws-mediastoredata_2.12-5.17.149.1-sources.jar: zio/aws/mediastoredata/model/package.scala <==
package zio.aws.mediastoredata
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.mediastoredata.model.primitives.StringPrimitive.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object ContentRangePattern extends Subtype[String]
    type ContentRangePattern =
      zio.aws.mediastoredata.model.primitives.ContentRangePattern.Type
    object ContentType extends Subtype[String]
    type ContentType = zio.aws.mediastoredata.model.primitives.ContentType.Type
    object ETag extends Subtype[String]
    type ETag = zio.aws.mediastoredata.model.primitives.ETag.Type
    object ItemName extends Subtype[String]
    type ItemName = zio.aws.mediastoredata.model.primitives.ItemName.Type
    object ListLimit extends Subtype[Int]
    type ListLimit = zio.aws.mediastoredata.model.primitives.ListLimit.Type
    object ListPathNaming extends Subtype[String]
    type ListPathNaming =
      zio.aws.mediastoredata.model.primitives.ListPathNaming.Type
    object NonNegativeLong extends Subtype[Long]
    type NonNegativeLong =
      zio.aws.mediastoredata.model.primitives.NonNegativeLong.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.mediastoredata.model.primitives.PaginationToken.Type
    object PathNaming extends Subtype[String]
    type PathNaming = zio.aws.mediastoredata.model.primitives.PathNaming.Type
    object PayloadBlob extends Subtype[Chunk[Byte]]
    type PayloadBlob = zio.aws.mediastoredata.model.primitives.PayloadBlob.Type
    object RangePattern extends Subtype[String]
    type RangePattern =
      zio.aws.mediastoredata.model.primitives.RangePattern.Type
    object SHA256Hash extends Subtype[String]
    type SHA256Hash = zio.aws.mediastoredata.model.primitives.SHA256Hash.Type
    object StatusCode extends Subtype[Int]
    type StatusCode = zio.aws.mediastoredata.model.primitives.StatusCode.Type
    object StringPrimitive extends Subtype[String]
    type StringPrimitive =
      zio.aws.mediastoredata.model.primitives.StringPrimitive.Type
    object TimeStamp extends Subtype[Instant]
    type TimeStamp = zio.aws.mediastoredata.model.primitives.TimeStamp.Type
  }
  type ItemList = List[zio.aws.mediastoredata.model.Item]
}

==> zio-aws-mediastoredata_3-5.17.169.1-sources.jar: zio/aws/mediastoredata/model/package.scala <==
package zio.aws.mediastoredata
import zio.prelude.Subtype
import zio.Chunk
import java.time.Instant
import zio.aws.mediastoredata.model.primitives.StringPrimitive.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object ContentRangePattern extends Subtype[String]
    type ContentRangePattern =
      zio.aws.mediastoredata.model.primitives.ContentRangePattern.Type
    object ContentType extends Subtype[String]
    type ContentType = zio.aws.mediastoredata.model.primitives.ContentType.Type
    object ETag extends Subtype[String]
    type ETag = zio.aws.mediastoredata.model.primitives.ETag.Type
    object ItemName extends Subtype[String]
    type ItemName = zio.aws.mediastoredata.model.primitives.ItemName.Type
    object ListLimit extends Subtype[Int]
    type ListLimit = zio.aws.mediastoredata.model.primitives.ListLimit.Type
    object ListPathNaming extends Subtype[String]
    type ListPathNaming =
      zio.aws.mediastoredata.model.primitives.ListPathNaming.Type
    object NonNegativeLong extends Subtype[Long]
    type NonNegativeLong =
      zio.aws.mediastoredata.model.primitives.NonNegativeLong.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.mediastoredata.model.primitives.PaginationToken.Type
    object PathNaming extends Subtype[String]
    type PathNaming = zio.aws.mediastoredata.model.primitives.PathNaming.Type
    object PayloadBlob extends Subtype[Chunk[Byte]]
    type PayloadBlob = zio.aws.mediastoredata.model.primitives.PayloadBlob.Type
    object RangePattern extends Subtype[String]
    type RangePattern =
      zio.aws.mediastoredata.model.primitives.RangePattern.Type
    object SHA256Hash extends Subtype[String]
    type SHA256Hash = zio.aws.mediastoredata.model.primitives.SHA256Hash.Type
    object StatusCode extends Subtype[Int]
    type StatusCode = zio.aws.mediastoredata.model.primitives.StatusCode.Type
    object StringPrimitive extends Subtype[String]
    type StringPrimitive =
      zio.aws.mediastoredata.model.primitives.StringPrimitive.Type
    object TimeStamp extends Subtype[Instant]
    type TimeStamp = zio.aws.mediastoredata.model.primitives.TimeStamp.Type
  }
  type ItemList = List[zio.aws.mediastoredata.model.Item]
}
